@@ -214,17 +214,17 @@ class LambdaToSns(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="snsTopic")
     def sns_topic(self) -> aws_cdk.aws_sns.Topic:
         return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "snsTopic"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
@@ -273,11 +273,11 @@ class LambdaToSnsProps:
         :summary: The properties for the LambdaToSns class.
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
-            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+            topic_props = TopicProps(**topic_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(LambdaToSnsProps.__init__)
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
